%% LAG selection 
%% Housekeeping 
clear; clc; close all hidden;
addpath('data_quarterly')
addpath('utilities')
addpath('ADF_test_functions')

%% Data loading 
load("dates.mat");
load("brentspot");
load('CPI_US')
load("RGDP_mainland.mat");
load("GECON.mat"); 
load("oilprod.mat");
load('KPI_Norway');
load("empl_oil_sector.mat");
load("wage_oil_sector.mat");
load("empl_industry_sector.mat");
load("wage_industry_sector.mat");
load("empl_MIME_sector.mat");
load("wage_MIME_sector.mat");
load("empl_BC_sector.mat");
load("wage_BC_sector.mat");
load("empl_SB_sector.mat");
load("wage_SB_sector.mat");
load("empl_FCA_sector.mat");
load("wage_FCA_sector.mat");
load("wage.mat");
load("employment.mat");

load("rgdp_EOGS.mat");
load("rgdp_FCA.mat");
load("rgdp_MIME.mat");
load("rgdp_BC.mat");
load("rgdp_SB.mat");

%% Data converting 
% Real values 
rop = (brentspot./CPI_US)*100; %Real oil price 
real_wage_oil_sector = (wage_oil_sector./KPI_Norway)*100; %Real wage 
real_wage_FCA_sector = (wage_FCA_sector./KPI_Norway)*100; %Real wage 
real_wage_BC_sector = (wage_BC_sector./KPI_Norway)*100; %Real wage 
real_wage_SB_sector = (wage_SB_sector./KPI_Norway)*100; %Real wage 
real_wage_MIME_sector = (wage_MIME_sector./KPI_Norway)*100; %Real wage 
real_wage_industry_sector = (wage_industry_sector./KPI_Norway)*100; %Real wage
real_wage= (wage./KPI_Norway)*100; %Real wage

%Detrended

real_wage_oil_sector_detrended = detrend(log(real_wage_oil_sector),1); %Real wage 
real_wage_FCA_sector_detrended = detrend(log(real_wage_FCA_sector),1); %Real wage
real_wage_MIME_sector_detrended = detrend(log(real_wage_MIME_sector),1); %Real wage
real_wage_BC_sector_detrended = detrend(log(real_wage_BC_sector),1); %Real wage
real_wage_industry_detrended = detrend(log(real_wage_industry_sector),1); %Real wage
real_wage_detrended = detrend(log(real_wage),1);
real_wage_SB_sector_detrended = detrend(log(real_wage_SB_sector),1); %Real wage

oilprod_detrended = detrend(oilprod,1);
rgdp_detrended = detrend(log(RGDP_mainland),1);
rgdp_detrended_EOGS = detrend(log(rgdp_EOGS),1);
rgdp_detrended_FCA = detrend(log(rgdp_FCA),1);
rgdp_detrended_MIME = detrend(log(rgdp_MIME),1);
rgdp_detrended_BC = detrend(log(rgdp_BC),1);
rgdp_detrended_SB = detrend(log(rgdp_SB),1);
rop_log=(log(rop));
empl_oil_sector_detrended = detrend(log(empl_oil_sector),1);
empl_FCA_sector_detrended = detrend(log(empl_FCA_sector),1);
empl_BC_sector_detrended = detrend(log(empl_BC_sector),1);
empl_SB_sector_detrended = detrend(log(empl_SB_sector),1);
empl_MIME_sector_detrended = detrend(log(empl_MIME_sector),1);
empl_industry_sector_detrended = detrend(log(empl_industry_sector),1);
employment_detrended = detrend(log(employment),1);

%% Choosing number of lags GCOP

yr   = oilprod_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [oilprod_detrended(6:end-1) oilprod_detrended(5:end-2) oilprod_detrended(4:end-3) oilprod_detrended(3:end-4) oilprod_detrended(2:end-5) oilprod_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags GECON
yr   = GECON(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [GECON(6:end-1) GECON(5:end-2) GECON(4:end-3) GECON(3:end-4) GECON(2:end-5) GECON(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion

%% Choosing number of lags ROP
yr   = rop_log(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rop_log(6:end-1) rop_log(5:end-2) rop_log(4:end-3) rop_log(3:end-4) rop_log(2:end-5) rop_log(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rgdp-ME
yr   = rgdp_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rgdp_detrended(6:end-1) rgdp_detrended(5:end-2) rgdp_detrended(4:end-3) rgdp_detrended(3:end-4) rgdp_detrended(2:end-5) rgdp_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rgdp-EOGS
yr   = rgdp_detrended_EOGS(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rgdp_detrended_EOGS(6:end-1) rgdp_detrended_EOGS(5:end-2) rgdp_detrended_EOGS(4:end-3) rgdp_detrended_EOGS(3:end-4) rgdp_detrended_EOGS(2:end-5) rgdp_detrended_EOGS(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion

%% Choosing number of lags rgdp-FCA
yr   = rgdp_detrended_FCA(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rgdp_detrended_FCA(6:end-1) rgdp_detrended_FCA(5:end-2) rgdp_detrended_FCA(4:end-3) rgdp_detrended_FCA(3:end-4) rgdp_detrended_FCA(2:end-5) rgdp_detrended_FCA(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rgdp-BC
yr   = rgdp_detrended_BC(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rgdp_detrended_BC(6:end-1) rgdp_detrended_BC(5:end-2) rgdp_detrended_BC(4:end-3) rgdp_detrended_BC(3:end-4) rgdp_detrended_BC(2:end-5) rgdp_detrended_BC(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion

%% Choosing number of lags rgdp-SY
yr   = rgdp_detrended_SB(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [rgdp_detrended_SB(6:end-1) rgdp_detrended_SB(5:end-2) rgdp_detrended_SB(4:end-3) rgdp_detrended_SB(3:end-4) rgdp_detrended_SB(2:end-5) rgdp_detrended_SB(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion

%% Choosing number of lags empl_ME_sector
yr   = employment_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [employment_detrended(6:end-1) employment_detrended(5:end-2) employment_detrended(4:end-3) employment_detrended(3:end-4) employment_detrended(2:end-5) employment_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags empl_oil_sector
yr   = empl_oil_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [empl_oil_sector_detrended(6:end-1) empl_oil_sector_detrended(5:end-2) empl_oil_sector_detrended(4:end-3) empl_oil_sector_detrended(3:end-4) empl_oil_sector_detrended(2:end-5) empl_oil_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags empl_FCA_sector
yr   = empl_FCA_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [empl_FCA_sector_detrended(6:end-1) empl_FCA_sector_detrended(5:end-2) empl_FCA_sector_detrended(4:end-3) empl_FCA_sector_detrended(3:end-4) empl_FCA_sector_detrended(2:end-5) empl_FCA_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags empl_MIME_sector
yr   = empl_MIME_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [empl_MIME_sector_detrended(6:end-1) empl_MIME_sector_detrended(5:end-2) empl_MIME_sector_detrended(4:end-3) empl_MIME_sector_detrended(3:end-4) empl_MIME_sector_detrended(2:end-5) empl_MIME_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags empl_BC_sector
yr   = empl_BC_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [empl_BC_sector_detrended(6:end-1) empl_BC_sector_detrended(5:end-2) empl_BC_sector_detrended(4:end-3) empl_BC_sector_detrended(3:end-4) empl_BC_sector_detrended(2:end-5) empl_BC_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags empl_SB_sector
yr   = empl_SB_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [empl_SB_sector_detrended(6:end-1) empl_SB_sector_detrended(5:end-2) empl_SB_sector_detrended(4:end-3) empl_SB_sector_detrended(3:end-4) empl_SB_sector_detrended(2:end-5) empl_SB_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rw_ME_sector
yr   = real_wage_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_detrended(6:end-1) real_wage_detrended(5:end-2) real_wage_detrended(4:end-3) real_wage_detrended(3:end-4) real_wage_detrended(2:end-5) real_wage_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion

%% Choosing number of lags rw_oil_sector
yr   = real_wage_oil_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_oil_sector_detrended(6:end-1) real_wage_oil_sector_detrended(5:end-2) real_wage_oil_sector_detrended(4:end-3) real_wage_oil_sector_detrended(3:end-4) real_wage_oil_sector_detrended(2:end-5) real_wage_oil_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rw_FCA_sector
yr   = real_wage_FCA_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_FCA_sector_detrended(6:end-1) real_wage_FCA_sector_detrended(5:end-2) real_wage_FCA_sector_detrended(4:end-3) real_wage_FCA_sector_detrended(3:end-4) real_wage_FCA_sector_detrended(2:end-5) real_wage_FCA_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rw_MIME_sector
yr   = real_wage_MIME_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_MIME_sector_detrended(6:end-1) real_wage_MIME_sector_detrended(5:end-2) real_wage_MIME_sector_detrended(4:end-3) real_wage_MIME_sector_detrended(3:end-4) real_wage_MIME_sector_detrended(2:end-5) real_wage_MIME_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rw_BC_sector
yr   = real_wage_BC_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_BC_sector_detrended(6:end-1) real_wage_BC_sector_detrended(5:end-2) real_wage_BC_sector_detrended(4:end-3) real_wage_BC_sector_detrended(3:end-4) real_wage_BC_sector_detrended(2:end-5) real_wage_BC_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion
%% Choosing number of lags rw_SB_sector
yr   = real_wage_SB_sector_detrended(7:end);
%       lag=1         lag=2         lag=3         lag=4 
ylag = [real_wage_SB_sector_detrended(6:end-1) real_wage_SB_sector_detrended(5:end-2) real_wage_SB_sector_detrended(4:end-3) real_wage_SB_sector_detrended(3:end-4) real_wage_SB_sector_detrended(2:end-5) real_wage_SB_sector_detrended(1:end-6)]; 
% Notice here how we loose observations due to the lag lengths 

% Now we can run 6 logferent AR models, one for each lag length, and then
% compare the results using AIC to find the best lag length
ar_6                    = fitlm(ylag, yr,  'Intercept', false);
ar_5                    = fitlm(ylag(:, 1 : 5), yr, 'Intercept', false);
ar_4                    = fitlm(ylag(:, 1 : 4), yr, 'Intercept', false);
ar_3                    = fitlm(ylag(:, 1 : 3), yr, 'Intercept', false);
ar_2                    = fitlm(ylag(:, 1 : 2), yr,  'Intercept', false);
ar_1                    = fitlm(ylag(:, 1), yr,  'Intercept', false);

% Compare information criterion across models

ar_6.ModelCriterion
ar_5.ModelCriterion
ar_4.ModelCriterion
ar_3.ModelCriterion
ar_2.ModelCriterion
ar_1.ModelCriterion