%% Robustness Check
%% Housekeeping and working directory 
clear; clc; close all hidden;
addpath('data_quarterly')
addpath('utilities')
addpath('ADF_test_functions')


%% Converting dates from numerical values to datetime
%%dates = datetime(Dates,'convertfrom', 'Excel');

%% Data loading 
load("dates.mat");
load("brentspot");
load('CPI_US');
load("RGDP_mainland.mat");
load("GECON.mat"); 
load("oilprod.mat");
load("employment.mat");
load('KPI_Norway');
load("wage.mat");


load("rgdp_EOGS.mat");
load("empl_oil_sector.mat");
load("wage_oil_sector.mat");

load("rgdp_FCA.mat");
load("empl_FCA_sector.mat");
load("wage_FCA_sector.mat");

load("rgdp_MIME.mat");
load("empl_MIME_sector.mat");
load("wage_MIME_sector.mat");

load("rgdp_BC.mat");
load("empl_BC_sector.mat");
load("wage_BC_sector.mat");

load("brentspot_robust.mat");
load('CPI_US_robust.mat');
load("NPO_DEC.mat")
load("NPO_INC.mat")

%% Converting Oil prices to real value 

rop = (brentspot_robust./CPI_US_robust)*100; %Real oil price 
real_wage = (wage./KPI_Norway)*100;

real_wage_oil_sector = (wage_oil_sector./KPI_Norway)*100;
real_wage_FCA_sector = (wage_FCA_sector./KPI_Norway)*100;
real_wage_MIME_sector = (wage_MIME_sector./KPI_Norway)*100;
real_wage_BC_sector = (wage_BC_sector./KPI_Norway)*100;

%% First difference of Natural log 

oilprod_detrended = detrend(log(oilprod),1);
rop_log=(log(rop));
rop_diff=100*diff(rop_log);

rgdp_detrended_ME = detrend(log(RGDP_mainland),1);
rgdp_diff_ME = 100*diff(log(RGDP_mainland));
employment_detrended_ME = detrend(log(employment),1);
real_wage_detrended_ME = detrend(log(real_wage),1);


rgdp_detrended_EOGS = detrend(log(rgdp_EOGS),1);
real_wage_oil_sector_detrended = detrend(log(real_wage_oil_sector),1);
empl_oil_sector_detrended = detrend(log(empl_oil_sector),1);

rgdp_detrended_FCA = detrend(log(rgdp_FCA),1);
real_wage_FCA_sector_detrended = detrend(log(real_wage_FCA_sector),1);
empl_FCA_sector_detrended = detrend(log(empl_FCA_sector),1);

rgdp_detrended_MIME = detrend(log(rgdp_MIME),1);
real_wage_MIME_sector_detrended = detrend(log(real_wage_MIME_sector),1);
empl_MIME_sector_detrended = detrend(log(empl_MIME_sector),1);

rgdp_detrended_BC = detrend(log(rgdp_BC),1);
real_wage_BC_sector_detrended = detrend(log(real_wage_BC_sector),1);
empl_BC_sector_detrended = detrend(log(empl_BC_sector),1);
%% Alternative Oil Price Measures 
figure(3) 
plot(dates(2:112),rop_diff(9:119))
title('Change in real oil price')
set(findobj(gcf,'type','Line'),'LineWidth', 1);

%% HAMILTON 1996 
%N PO INCREASE
figure(3) 
plot(dates,NPO_INC)
title('Net Price of Oil Increase (Hamilton, 1996)')
set(findobj(gcf,'type','Line'),'LineWidth', 1);

% NPO DECREASE 
figure(4) 
plot(dates,NPO_DEC)
title('Net Price of Oil Decrease (Hamilton 1996)')
set(findobj(gcf,'type','Line'),'LineWidth', 1);

%% MORK 1989


% RPO INCREASE
RPO_INC = max(0,rop_diff);

figure(5)
plot(dates(2:112),RPO_INC(9:119))
title('Real Price of Oil Increase (Mork 1989)')
set(findobj(gcf,'type','Line'),'LineWidth', 1);
% RPO DECREASE
RPO_DEC = min(0,rop_diff);

figure(6)
plot(dates(2:112),RPO_DEC(9:119))
title('Real Price of Oil Decrease (Mork 1989)')
set(findobj(gcf,'type','Line'),'LineWidth', 1);

%
A = corr(rop_diff(8:119),NPO_INC)

B = corr(rop_diff(8:119),NPO_DEC)

C = corr(rop_diff(8:119),RPO_INC(8:119))

D = corr(rop_diff(8:119),RPO_DEC(8:119))
%% Assymetry test 
%GDP

%%
[h,p,ci,stats] = vartest2(rgdp_detrended_ME,NPO_INC) % 0.8808 % 4.7822e+03
%%
[h,p,ci,stats] = vartest2(rgdp_detrended_ME,NPO_DEC) % 0.3562 % 1.9339e+03
%%
[h,p,ci,stats] = vartest2(rgdp_detrended_ME,RPO_INC(8:119)) % 4.7714e-05 % 0.2591
%%
[h,p,ci,stats] = vartest2(rgdp_detrended_ME,RPO_DEC(8:119)) % 2.6071e-05 % 0.1415
 
%%

